@@ -1,6 +1,7 @@
 from __future__ import absolute_import
 
+from .admin import TablibAdmin
 from .fields import Field
 from .models import ModelDataset, NoObjectsException
 
-__all__ = [Field, ModelDataset, NoObjectsException]
+__all__ = [Field, ModelDataset, NoObjectsException, TablibAdmin]
